@@ -958,10 +958,10 @@ compare_tasks  (GtkTreeModel *model,
 	else {
                 GTime due_time_a, due_time_b;
 
-                gtk_tree_model_get (model, a, TASK_COLUMN_DUE_TIME,
-                                    &due_time_a, G_MAXINT32);
-                gtk_tree_model_get (model, b, TASK_COLUMN_DUE_TIME,
-                                    &due_time_b, G_MAXINT32);
+                gtk_tree_model_get (model, a,
+				    TASK_COLUMN_DUE_TIME, &due_time_a, -1);
+                gtk_tree_model_get (model, b,
+				    TASK_COLUMN_DUE_TIME, &due_time_b, -1);
 
                 if (due_time_a < due_time_b)
                         return -1;
@@ -1238,15 +1238,29 @@ create_appointment_list (ClockData  *cd,
 }
 
 static void
-calendar_day_activated (ClockData *cd)
+calendar_day_activated (ClockData   *cd,
+			GtkCalendar *calendar)
 {
-        /* FIXME: should be able to launch the editor for
-         *        the specific day
-         */
-        calendar_client_launch_editor (cd->client,
-                                       CALENDAR_EVENT_APPOINTMENT,
-                                       gtk_widget_get_screen (cd->calendar),
-                                       NULL);
+	unsigned int  day;
+	unsigned int  month;
+	unsigned int  year;
+	char         *command_line;
+	GError       *error;
+
+	gtk_calendar_get_date (GTK_CALENDAR (cd->calendar),
+			       &year, &month, &day);
+
+	command_line = g_strdup_printf ("evolution "
+					"calendar:///?startdate=%.4d%.2d%.2d",
+					year, month + 1, day);
+
+	if (!gdk_spawn_command_line_on_screen (gtk_widget_get_screen (cd->calendar),
+					       command_line, &error)) {
+		g_printerr ("Cannot launch calendar: %s\n", error->message);
+		g_error_free (error);
+	}
+
+	g_free (command_line);
 }
 
 static void
@@ -1873,6 +1887,7 @@ try_config_tool (GdkScreen  *screen,
 					 GTK_BUTTONS_OK,
 					 _("Failed to launch time configuration tool: %s"),
 					 err->message);
+	g_error_free (err);
 		
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (gtk_widget_destroy), NULL);
@@ -2673,20 +2688,10 @@ display_help_dialog (BonoboUIComponent *uic,
 		     const gchar       *verbname)
 {
 	GError *error = NULL;
-	static GnomeProgram *applet_program = NULL;
 
-	if (!applet_program) {
-		int argc = 1;
-		char *argv[2] = { "clock" };
-		applet_program = gnome_program_init ("clock", VERSION,
-						      LIBGNOME_MODULE, argc, argv,
-						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
-	}
-
-	gnome_help_display_desktop_on_screen (
-			applet_program, "clock", "clock",NULL,
-			gtk_widget_get_screen (cd->applet),
-			&error);
+	gnome_help_display_desktop_on_screen (NULL, "clock", "clock", NULL,
+					      gtk_widget_get_screen (cd->applet),
+					      &error);
 	if (error) {
 		GtkWidget *dialog;
 		dialog = gtk_message_dialog_new (NULL,
