@@ -24,6 +24,7 @@
 #include "panel-applet-frame.h"
 #include "panel-action-button.h"
 #include "panel-menu-bar.h"
+#include "panel-separator.h"
 #include "panel-compatibility.h"
 #include "panel-toplevel.h"
 #include "panel-util.h"
@@ -64,6 +65,7 @@ panel_applet_set_dnd_enabled (AppletInfo *info,
 						     dnd_enabled);
 		break;
 	case PANEL_OBJECT_MENU_BAR:
+	case PANEL_OBJECT_SEPARATOR:
 		break;
 	default:
 		g_assert_not_reached ();
@@ -269,6 +271,8 @@ applet_callback_callback (GtkWidget      *widget,
 		 * Applet's menu's are handled differently
 		 */
 		break;
+	case PANEL_OBJECT_SEPARATOR:
+		break;
 	default:
 		g_assert_not_reached ();
 		break;
@@ -533,7 +537,7 @@ panel_applet_create_menu (AppletInfo *info)
 		gtk_widget_show (menuitem);
 
 		menuitem = gtk_check_menu_item_new ();
-		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, _("_Lock To Panel"), FALSE);
+		setup_menuitem (menuitem, GTK_ICON_SIZE_MENU, NULL, _("Loc_k To Panel"), FALSE);
 		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
 						locked);
 		g_signal_connect (menuitem, "toggled",
@@ -896,6 +900,11 @@ panel_applet_load_idle_handler (gpointer dummy)
 				TRUE,
 				applet->id);
 		break;
+	case PANEL_OBJECT_SEPARATOR:
+		panel_separator_load_from_gconf (panel_widget,
+						 applet->locked,
+						 applet->position,
+						 applet->id);
 	default:
 		break;
 	}
